<?php

use duncan3dc\Laravel\BladeInstance;
use JasonGrimes\Paginator;

function view($template, $data = [], $echo = true)
{
	$blade = new BladeInstance(__DIR__ . '/../themes', __DIR__ . '/../cache/view');
	$blade->addPath(__DIR__ . '/../parts');
	if(!$echo){
		return $blade->render($template, $data);
	}
	echo $blade->render($template, $data);
}

function home_url()
{
	if (php_sapi_name() == "cli") {
    	return '';
	}
	$protocol = ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
	$url = $protocol . $_SERVER['HTTP_HOST'] . str_replace('/index.php', '', Flight::request()->base);
	return rtrim($url, '/') . '/';
}

function asset( $file )
{
    return home_url() . 'themes/' . config( 'theme' ) . '/' . $file;
}

function tmdb()
{
	$api_tmdb = config('api_tmdb');
	shuffle($api_tmdb);
	$tmdb = new TMDB( $api_tmdb[0] );
	return $tmdb;
}

function img_url( $size, $path, $photon = false )
{
    if ($photon) {
		return "//i1.wp.com/image.tmdb.org/t/p/{$size}{$path}?resize=300,450";
	}
	return "https://image.tmdb.org/t/p/{$size}{$path}";
}

function pagination($total_results, $slug, $page)
{
	if ($total_results > 1) {
		if ($total_results > 1000) {
			$total_results = 1000;
		}
		$limit  = 20;
		$link = '/'.$slug;
		$pagination = new Pagination($total_results, $limit, $link, '/');
		$pagination->setPage($page);
		echo $pagination->showPage();
	}
}

function rating($vote_average)
{
	for ($i=0; $i < 10; $i++) {
		if ($i < floor($vote_average)) {
			echo '<i class="fas fa-star text-warning"></i>';
		}elseif($i < floor($vote_average) + 1){
			echo '<i class="fas fa-star-half-alt text-warning"></i>';
		}else{
			echo '<i class="far fa-star text-warning"></i>';
		}
	}
}

function release_date($release_date)
{
	return date('M d, Y', strtotime($release_date));
}

function minToHour($min)
{
	$d = floor ($min / 1440);
	$h = floor (($min - $d * 1440) / 60);
	$m = $min - ($d * 1440) - ($h * 60);

	if ($min < 60) {
		return "{$m}m";
	}
	return "{$h}h {$m}m";
}

function genres($genres)
{
	$gen = [];
	foreach ($genres as $key => $genre) {
		$gen[$key] = '<a href="'.build_permalink('genre/'.str_slug($genre['name']).'/'.$genre['id']).'">'.$genre['name'].'</a>';
	}
	return implode(', ', $gen);
}

function starts($genres)
{
	$gen = [];
	foreach ($genres as $key => $genre) {
		$gen[$key] = '<a href="'.build_permalink('people/'.str_slug($genre['name']).'/'.$genre['id']).'">'.$genre['name'].'</a>';
	}
	return implode(', ', $gen);
}

function filter_bad($results, $bad_id)
{
	$data = collect($results);
	if (isset($results['results'])) {
		$results = collect($results['results']);
		$bad_id = $results->whereNotIn('id', $bad_id)->all();
		$pull = $data->pull('results');
		$put = $data->put('results', $bad_id)->all();
	}else{
		$results = collect($results['cast']);
		$bad_id = $results->whereNotIn('id', $bad_id)->all();
		$pull = $data->pull('cast');
		$put = $data->put('cast', $bad_id)->all();
	}
	$data = $put;
	return $data;
}

function filter_bad_simrec($results, $bad_id)
{
	$results = collect($results);
	return $results->whereNotIn('id', $bad_id)->all();
}

function build_permalink( $add = '', $plus = [] ) {
	$link = home_url().$add;
	$arr = [];
	if (isset($_REQUEST['sub_id'])) {
		$arr = [ 'sub_id' => $_REQUEST['sub_id'] ];
		$merge = array_merge($plus, $arr);
		$http_build_query = http_build_query($merge);
		$link = home_url().$add.'?'.$http_build_query;
		// $link = (empty($add)) ? home_url().'?'.$http_build_query : $link;
	}elseif (!isset($_REQUEST['sub_id']) && !empty($plus)) {
		$http_build_query = http_build_query($plus);
		$link = home_url().$add.'?'.$http_build_query;
	}
	return $link;
}