<?php


class TMDB
{
	const _API_URL_ = "https://api.themoviedb.org/3/";

	public $api_key;

	public function __construct($api_key)
	{
		$this->api_key = $api_key;
	}

	public function _call($url)
	{
		if(function_exists("curl_init")){
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
			$content = curl_exec($ch);
			curl_close($ch);
			return $content;
		} else {
			return file_get_contents($url);
		}
	}

	public function api_key()
	{
		return config('api_key');
	}

	public function getSearch($query, $page = 1)
	{
		$kw = str_replace('-', ' ',$query);

		$url_movie = self::_API_URL_."search/movie?api_key={$this->api_key}&page={$page}&query={$kw}";
		$call_movie = json_decode($this->_call($url_movie), true);
		$call_movie = filter_bad($call_movie, config('bad_movie'));

		$url_tv = self::_API_URL_."search/tv?api_key={$this->api_key}&page={$page}&query={$kw}";
		$call_tv = json_decode($this->_call($url_tv), true);
		$call_tv = filter_bad($call_tv, config('bad_tv'));


		$url_person = self::_API_URL_."search/person?api_key={$this->api_key}&page={$page}&query={$kw}";
		$call_person = $this->_call($url_person);

		$rows = [
			'movie' => $call_movie,
			'tv' => $call_tv,
			'person' => json_decode($call_person, true),
			'name' => $query
		];
		return $rows;
	}

	public function getPeoplePopular($page = 1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getPeoplePopular'.$page;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."person/popular?api_key={$this->api_key}&page={$page}";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getPeopleMovies($id, $page = 1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getpeoplemovies'.$id.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_."person/{$id}/movie_credits?api_key={$this->api_key}&page={$page}";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getGenreMovies($id, $page = 1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getGenreMovies'.$id.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_."genre/{$id}/movies?api_key={$this->api_key}&page={$page}";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getKeywords($id, $page = 1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getKeywords'.$id.$page;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."keyword/{$id}/movies?api_key={$this->api_key}&page={$page}";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getMovie($id)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getMovie'.$id;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."movie/{$id}?api_key={$this->api_key}&append_to_response=credits,keywords,videos,images,similar,recommendations";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getTvSeasonEpisode($tv_id, $season_number, $episode_number)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getTvSeasonEpisode'.$tv_id.$season_number.$episode_number;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."tv/{$tv_id}/season/{$season_number}/episode/{$episode_number}?api_key={$this->api_key}&append_to_response=credits,videos,images,similar,recommendations";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getTvSeason($tv_id, $season_number)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getTvSeason'.$tv_id.$season_number;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."tv/{$tv_id}/season/{$season_number}?api_key={$this->api_key}&append_to_response=credits,videos,images,similar,recommendations";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getTv($id)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getTv'.$id;

		if($data = $cache->get_cache($label)) {
			return json_decode($data, true);
		} else {
			$url = self::_API_URL_."tv/{$id}?api_key={$this->api_key}&append_to_response=credits,videos,images,similar,recommendations,keywords";
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return json_decode($data, true);
		}
	}

	public function getNowPlayingMovies($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getNowPlayingMovies'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_.'movie/now_playing?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getPopularMovies($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getPopularMovies'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_.'movie/popular?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getTopRatedMovies($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getTopRatedMovies'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_.'movie/top_rated?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getUpcomingMovies($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getUpcomingMovies'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_movie'));
		} else {
			$url = self::_API_URL_.'movie/upcoming?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_movie'));
		}
	}

	public function getOnTheAirTVShows($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getOnTheAirTVShows'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_tv'));
		} else {
			$url = self::_API_URL_.'tv/on_the_air?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_tv'));
		}
	}

	public function getAiringTodayTVShows($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getAiringTodayTVShows'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_tv'));
		} else {
			$url = self::_API_URL_.'tv/airing_today?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_tv'));
		}
	}

	public function getPopularTVShows($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getPopularTVShows'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_tv'));
		} else {
			$url = self::_API_URL_.'tv/popular?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_tv'));
		}
	}

	public function getTopRatedTVShows($page=1)
	{
		$cache = new Cache;
		$cache->cache_time = config('cache_time');
		$label = 'getTopRatedTVShows'.$page;

		if($data = $cache->get_cache($label)) {
			return filter_bad(json_decode($data, true), config('bad_tv'));
		} else {
			$url = self::_API_URL_.'tv/top_rated?api_key='.$this->api_key.'&page='.$page;
			$data = $this->_call($url);
			$cache->set_cache($label, $data);
			return filter_bad(json_decode($data, true), config('bad_tv'));
		}
	}
}
