<?php

// home.blade.php // for homepage
// watch.blade.php // for single page movies
// archive.blade.php // for page genres, people, and movies/TV popular, top rated,..
// watch_tv.blade.php // for single page TV show, Tv season, and Tv episode
// loading.blade.php // For redirect to offer link
// search.blade.php // for search page

Flight::route('/', function(){
    if (isset($_REQUEST['s'])) {
        Flight::redirect(build_permalink('search/' . str_slug($_REQUEST['s'])), 301);
    }

    $rows = [
        'movie' => tmdb()->getNowPlayingMovies(),
        'tv' => tmdb()->getAiringTodayTVShows(),
    ];
    view(config('theme') . '.home', $rows);
});

// ====================
// Movies
// ====================

Flight::route('/movie/@id(/@slug)', function($id, $slug){
    if (in_array($id, config('bad_movie'))) {
        Flight::redirect(home_url(), 301);
    }
    $rows = tmdb()->getMovie($id);
    view(config('theme') . '.watch', $rows);
});

Flight::route('/movie-popular(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/movie-popular', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getPopularMovies($page),
        'name' => 'Popular Movies',
        'slug' => 'movie-popular',
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/movie-now-playing(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/movie-now-playing', 301);
    }

    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getNowPlayingMovies($page),
        'name' => 'Now Playing Movies',
        'slug' => 'movie-now-playing',
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/movie-top-rated(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/movie-top-rated', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getTopRatedMovies($page),
        'name' => 'Top Rated Movies',
        'slug' => 'movie-top-rated',
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/movie-upcoming(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/movie-upcoming', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getUpcomingMovies($page),
        'name' => 'Upcoming Movies',
        'slug' => 'movie-upcoming',
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

// ====================
// TV Shows
// ====================

Flight::route('/tv/@id-@season_number-@episode_number(/@slug)', function($id, $season_number, $episode_number){
    if (in_array($id, config('bad_tv'))) {
        Flight::redirect(home_url(), 301);
    }
    $rows = [
        'tv' => tmdb()->getTv($id),
        'season' => tmdb()->getTvSeason($id, $season_number),
        'episode' => tmdb()->getTvSeasonEpisode($id, $season_number, $episode_number)
    ];
    view(config('theme') . '.watch_tv', $rows);
});

Flight::route('/tv/@id-@season_number(/@slug)', function($id, $season_number){
    if (in_array($id, config('bad_tv'))) {
        Flight::redirect(home_url(), 301);
    }
    $rows = [
        'tv' => tmdb()->getTv($id),
        'season' => tmdb()->getTvSeason($id, $season_number)
    ];
    view(config('theme') . '.watch_tv', $rows);
});

Flight::route('/tv/@id(/@slug)', function($id){
    if (in_array($id, config('bad_tv'))) {
        Flight::redirect(home_url(), 301);
    }
    $rows = [
        'tv' => tmdb()->getTv($id)
    ];
    view(config('theme') . '.watch_tv', $rows);
});

Flight::route('/tv-popular(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/tv-popular', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getPopularTVShows($page),
        'name' => 'Popular Tv Shows',
        'slug' => 'tv-popular',
        'page' => $page,
        'type' => 'tv'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/tv-top-rated(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/tv-top-rated', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getTopRatedTVShows($page),
        'name' => 'Top Rated Tv Shows',
        'slug' => 'tv-top-rated',
        'page' => $page,
        'type' => 'tv'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/tv-airing-to-day(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/tv-airing-to-day', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getAiringTodayTVShows($page),
        'name' => 'Airing to Day Tv Shows',
        'slug' => 'tv-airing-to-day',
        'page' => $page,
        'type' => 'tv'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/tv-on-the-air(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect('/tv-on-the-air', 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getOnTheAirTVShows($page),
        'name' => 'On The Air Tv Shows',
        'slug' => 'tv-on-the-air',
        'page' => $page,
        'type' => 'tv'
    ];
    view(config('theme') . '.archive', $rows);
});

// ====================
// Other
// ====================

Flight::route('/genre/@slug/@id(/@page)', function($slug, $id, $page){
    if ($page == 1) {
        Flight::redirect("/genre/{$slug}/{$id}", 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getGenreMovies($id, $page),
        'name' => ucwords(str_replace('-', ' ', $slug)),
        'id' => $id,
        'slug' => 'genre/'.$slug.'/'.$id,
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/keyword/@id/@slug(/@page)', function($id, $slug, $page){
    if ($page == 1) {
        Flight::redirect("/keyword/{$id}/{$slug}", 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getKeywords($id, $page),
        'name' => ucwords(str_replace('-', ' ', $slug)),
        'id' => $id,
        'slug' => 'keyword/'.$id.'/'.$slug,
        'page' => $page,
        'type' => 'movie'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/people/@slug/@id(/@page)', function($slug, $id, $page){
    if ($page == 1) {
        Flight::redirect("/people/{$id}/{$slug}", 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getPeopleMovies($id, $page),
        'name' => ucwords(str_replace('-', ' ', $slug)),
        'id' => $id,
        'slug' => 'people/'.$slug.'/'.$id,
        'page' => $page,
        'type' => 'people'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/people(/@page)', function($page){
    if ($page == 1) {
        Flight::redirect("/people", 301);
    }
    $page = isset($page) ? $page : 1;
    $rows = [
        'rows' => tmdb()->getPeoplePopular($page),
        'name' => 'People',
        'slug' => 'people',
        'page' => $page,
        'type' => 'person'
    ];
    view(config('theme') . '.archive', $rows);
});

Flight::route('/search/@keyword', function($keyword){
    $rows = tmdb()->getSearch($keyword);
    view(config('theme').'.search', $rows);
});

Flight::route('/loading', function(){
    $sub_id = (isset($_REQUEST['sub_id'])) ? $_REQUEST['sub_id'] : '';
    view(config('theme').'.loading', ['sub_id' => $sub_id]);
});

Flight::route('/pages/@page', function($page){
    view(config('theme').'.pages.page', ['page' => $page]);
});

Flight::route('/sitemap(-@page).xml', function($page){
    if ($page == 'movie') {
        require 'sitemap/sitemap-movie.php';
    }elseif ($page == 'tv') {
        require 'sitemap/sitemap-tv.php';
    }else {
        require 'sitemap/sitemap.php';
    }
});

Flight::route('/clear', function() {
    $password = 'mopie';
    if ( !isset($_GET['pass']) || $_GET['pass'] !== $password ) {
        die;
    }
    foreach (glob('cache/data/*') as $file) {
        unlink($file);
    }
    foreach (glob('cache/view/*') as $file) {
        unlink($file);
    }
    echo "clear data and view success!";
});

Flight::start();