@extends(config('theme') . '.layouts')

@php
    $backdrop = isset($episode) ? [['file_path' => $episode['still_path']]] : $tv['images']['backdrops'];
    shuffle($backdrop);
    $backdrop = (!empty($backdrop)) ? $backdrop[0]['file_path'] : '';
    if (isset($episode)) {
        $url_redirect_loading = build_permalink('loading', [
            'id'=>$tv['id'],
            'title'=>$tv['name'],
            'season'=>$season['season_number'],
            'episode'=>$episode['episode_number']
            ]);
    }elseif(isset($season)){
        $url_redirect_loading = build_permalink('loading', [
            'id'=>$tv['id'],
            'title'=>$tv['name'],
            'season'=>$season['season_number']
            ]);
    }else{
        $url_redirect_loading = build_permalink('loading', ['id'=>$tv['id'], 'title'=>$tv['name']]);
    }
@endphp

@section('head')
    @if(isset($episode))
        <title>Watch {{ $tv['name'] }} - {{ $season['name'] }} Episode {{ $episode['episode_number'] }} : {{ $episode['name'] }} HD Free TV Show - {{ config('site_name') }}</title>
    @elseif(isset($season))
        <title>Watch {{ $tv['name'] }} - {{ $season['name'] }} HD Free TV Show - {{ config('site_name') }}</title>
    @else
        <title>Watch {{ $tv['name'] }} HD Free TV Show - {{ config('site_name') }}</title>
    @endif
@endsection

@section('content')
    <div class="pad"></div>
    <div class="main-content main-detail">
        <div class="main-content main-category">
            <div style="text-align: center; margin-bottom: 10px;">
            </div>

            <div id="mv-info">
                <div id="player-on" class="thumb pointer oncontext mvi-cover">
                    <div class="btn-play"></div>
                    <div class="loading-on"></div>
                    <img src="{{ img_url('original', $backdrop ) }}" alt="{{$tv['name']}}" class="img-responsive">
                </div>

                <div id="list-eps">
                    @isset($season)
                        <div class="list-group le-season" style="margin: 12px 10px;">
                            <h5>All Episode in {{ $season['name'] }}</h5>
                            @foreach ($season['episodes'] as $episode_item)
                                <a href="{{ build_permalink( 'tv/' . $tv['id'] .'-'.$episode_item['season_number']. '-' . $episode_item['episode_number']. '/' . str_slug($tv['name']) ) }}" class="list-group-item">{{ $episode_item['episode_number']. '. ' . $episode_item['name'] }}</a>
                            @endforeach
                        </div>
                    @endisset

                    <div class="list-group le-season" style="margin: 12px 10px;">
                        <h5>Season List</h5>
                        @foreach ($tv['seasons'] as $season_item)
                            <a href="{{ build_permalink( 'tv/' . $tv['id'] .'-'.$season_item['season_number']. '/' . str_slug($tv['name']) ) }}" class="list-group-item">{{ $tv['name'].' '.$season_item['name'] }}</a>
                        @endforeach
                    </div>
                </div>

                <div class="mvi-content">
                    <div class="mvic-btn">
                        <div class="mv-rating">
                            <h3>Trailer Movies</h3>
                            @foreach (collect($tv['videos']['results']) as $key => $trailer)
                                @if ($trailer['site'] == 'YouTube')
                                    @if ($key < 1)
                                        <div class="embed-responsive embed-responsive-16by9" style="margin-bottom:14px">
                                            <iframe class="embed-responsive-item" src="https://www.youtube.com/embed/{{$trailer['key']}}"></iframe>
                                        </div>
                                    @endif
                                @endif
                            @endforeach

                            <div class="clearfix"></div>
                        </div>
                        <div class="clearfix"></div>
                    </div>
                    <div class="thumb mvic-thumb" style="background-image: url({{ img_url('w300', $tv['poster_path'] ) }});"></div>
                    <div class="mvic-desc">
                        <h3>{{$tv['name']}}</h3>
                        <div class="desc">
                            <p>{{ $tv['overview'] }}</p>
                        </div>
                        <div class="mvic-info">
                            <div class="mvici-left">
                                <p><strong>First Release:</strong> {{ release_date($tv['first_air_date']) }}</p>
                                <p><strong>Duration:</strong> {{ minToHour($tv['episode_run_time'][0]) }}</p>
                                <p><strong>Quality:</strong> <span class="quality">HD</span></p>
                                <p><strong>Genres: </strong> {!! collect($tv['genres'])->implode('name', ', ') !!}</p>
                            </div>
                            <div class="mvici-right">
                                <p><strong>Actors: </strong> {!! starts(collect($tv['credits']['cast'])->take(10)) !!}</p>
                                <p><strong>Companies: </strong> {{ collect($tv['production_companies'])->implode('name', ', ') }}</p>
                            </div>
                            <div class="clearfix"></div>
                        </div>
                        <div class="clearfix"></div>
                    </div>
                    <div class="clearfix"></div>
                </div>
            </div>

        </div>

        <div id="mv-keywords">
        </div>

        <div class="movies-list-wrap mlw-related">
            <div class="ml-title ml-title-page">
                <span>You May Also Like</span>
            </div>
            <div class="movies-list movies-list-full">
                @foreach ( filter_bad_simrec($tv['recommendations']['results'], config('bad_tv') ) as $item)
                    @include(config('theme').'._tv_loop')
                @endforeach
            </div>
        </div>

        @include(config('theme').'._modal', ['backdrop' => $backdrop, 'url_redirect_loading' => $url_redirect_loading])
    </div>
@endsection